@@ -21,40 +21,46 @@
 #' iterations.)  To avoid this, integers over 2^22 that differ by a value of
 #' 8 or less are treated as equal.
 #' 
-#' NB. At present, only square matrices are supported; if you need support for 
-#' non-square matrices, drop a note at 
-#' [issue #25](https://github.com/ms609/TreeDist/issues/25)
-#' and I'll prioritize development.
-#' 
 #' @references \insertAllCited{}
 #'
-#' @author [C++ code](https://github.com/yongyanghz/LAPJV-algorithm-c/blob/master/LAPJV/lap.cpp)
+#' @author [C++ code](
+#' https://github.com/yongyanghz/LAPJV-algorithm-c/blob/master/LAPJV/lap.cpp)
 #' by Roy Jonker, MagicLogic Optimization Inc. <roy_jonker@magiclogic.com>, 
 #' with contributions from Yong Yang <yongyanglink@gmail.com>, after 
 #' [Yi Cao](https://uk.mathworks.com/matlabcentral/profile/authors/69713-yi-cao)
 #' 
-#' @param x Square matrix of costs.
-#' @return A list with two entries: `score`, the score of the optimal matching;
+#' @param x Matrix of costs.
+#' @return `LAPJV()` returns a list with two entries: `score`, the score of the
+#' optimal matching;
 #' and `matching`, the columns matched to each row of the matrix in turn.
 #' 
 #' @examples 
-#' problem <- matrix(c(7, 9, 8, 9,
-#'                     2, 8, 5, 7,
-#'                     1, 6, 6, 9,
-#'                     3, 6, 2, 2), 4, 4, byrow=TRUE)
+#' problem <- matrix(c(7, 9, 8, 9, 9,
+#'                     2, 8, 5, 7, 9,
+#'                     1, 6, 6, 9, 9,
+#'                     3, 6, 2, 2, 9), 4, 5, byrow = TRUE)
 #'
 #' LAPJV(problem)
+#' @seealso 
+#' Implementations of the Hungarian algorithm exist in \pkg{adagio},
+#' \pkg{RcppHungarian}, and \pkg{clue} and \pkg{lpSolve}; for larger matrices,
+#' these are substantially slower. (See discussion at [Stack Overflow](
+#' https://stackoverflow.com/questions/72806265/).)
+#' 
+#' The JV algorithm is implemented for square matrices in the Bioconductor
+#' package [`GraphAlignment::LinearAssignment()`](
+#' https://www.bioconductor.org/packages/release/bioc/html/GraphAlignment.html).
+#' 
 #' @export
 LAPJV <- function(x) {
   dims <- dim(x)
-  if (length(dims) == 2L && 
-      identical(dims[1], dims[2])) {
-    if (dims[1] == 0L) {
+  if (length(dims) == 2L) {
+    if (any(dims == 0L)) {
       integer(0)
     } else {
       lapjv(x, max(x))
     }
   } else {
-    stop("x must be a square matrix")
+    stop("x must be a two-dimensional matrix")
   }
 }
