@@ -2,7 +2,7 @@
 #define _TREEDIST_TREE_DISTANCES_H
 
 #include <TreeTools/SplitList.h>
-#include <Rcpp.h>
+#include <Rcpp/Lightest>
 
 #include <limits> /* for numeric_limits */
 
